Pytex
=====

Pytex is a simple package which make aa bridge between Latex and Python.

texenv: Bring Python inside latex
---------------------------------

*texenv* is a jinja2 environment which allow to use python commands inside latex.

- **\Block{#}**  is the equivalent of **{% block #%}** in Jinja2. Every python's commands will be run like in a script. **%-** is also available for line statement.
- **\Var{#}** is the equivalent of **{{#}}** which print the statment.


feed: converting template into tex files
----------------------------------------

pdflatex: Compile files with pdflatex
-------------------------------------

update_export_dict: import extract tools inside template
--------------------------------------------------------



